﻿using BMICalculator.BL.Interfaces;
using BMICalculator.Shared;
using BMICalculator.Shared.Enums;
using BMICalculator.Shared.Models;
using System;

namespace BMICalculator.BL.Services
{
    public class BMICalculator : IBMICalculator
    {
        public BMIResult CalculateBMI(PersonDescriptor person)
        {
            if (person == null)
                throw new ArgumentNullException(nameof(person));

            // Calculate age
            var age = DateTime.Now.Year - person.BirthDate.Year;

            // Convert centimeter
            var heightInMeter = person.Height / 100;

            var result = new BMIResult();

            // Calculate BMI
            result.BMI = person.Weight / Math.Pow(heightInMeter, 2);

            // Get BMI result
            result.Result = GetBMIResultByBMI(result.BMI, person.Gender);

            // Define expected status of BMI
            result.IsInTheExpectedRange = GetExpectedRangeStatus(result.BMI, age);

            return result;
        }

        private bool GetExpectedRangeStatus(double bmi, int age)
        {
            if (age < 19)
            {
                return false;
            }
            else if (age < 25)
            {
                return bmi >= 19 && bmi <= 25;
            }
            else if (age < 35)
            {
                return bmi >= 20 && bmi <= 25;
            }
            else if (age < 45)
            {
                return bmi >= 21 && bmi <= 26;
            }
            else if (age < 55)
            {
                return bmi >= 22 && bmi <= 27;
            }
            else if (age < 65)
            {
                return bmi >= 23 && bmi <= 28;
            }
            else
            {
                return bmi >= 24 && bmi <= 29;
            }
        }

        private BMIResults GetBMIResultByBMI(double bmi, Genders gender)
        {
            if (gender == Genders.Female || gender == Genders.Male)
            {
                if (bmi < 18.5)
                {
                    return BMIResults.Underweight;
                }
                else if (bmi < 25)
                {
                    return BMIResults.Normal;
                }
                else if (bmi < 30)
                {
                    return BMIResults.Overweigth;
                }
                else if (bmi < 35)
                {
                    return BMIResults.Obese;
                }
                else
                {
                    return BMIResults.ExtremelyObese;
                }
            }

            throw new NotImplementedException("The given gender BMI calculation is not implemented yet.");
        }
    }
}
