﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Threading.Tasks;
using WebApplication1.Models;

namespace WebApplication1.Controllers
{
    public class CalorieCalcController : Controller
    {
        List<Exercise> Exercises;
        public CalorieCalcController()
        {
            Exercises = new List<Exercise>();
            Exercises.Add(new Exercise("Running", 1000));
            Exercises.Add(new Exercise("Yoga", 400));
            Exercises.Add(new Exercise("Pilates", 472));
            Exercises.Add(new Exercise("Hiking", 700));
            Exercises.Add(new Exercise("Swimming", 1000));
            Exercises.Add(new Exercise("Bicycle", 600));
        }
        // GET: CalorieCalc/Form
        public IActionResult Form()
        {
            return View("CalorieInput", Exercises);
        }

        // POST: CalorieCalc/Calc
        [HttpPost]
        public IActionResult Calc(CalorieInput input)
        {
            if (!Request.Form.Keys.Contains(nameof(CalorieInput.Name))) 
            {
                TempData["myWarning"] = "MISSING DATA";
                return this.RedirectToAction(nameof(Form));
            }
            if (input.Length < 0) // and verify weight, selected index, name ...
            {
                TempData["myWarning"] = "INVALID DATA";
                return this.RedirectToAction(nameof(Form));
            }

            double weightMultiplier = input.Weight / 100;
            double lengthMultiplier = input.Length / 60;
            Exercise selectedExercise = input.SelectedExercise < Exercises.Count ? Exercises[input.SelectedExercise] : null;
            CalorieOutput output = new CalorieOutput()
            {
                Input = input,
                SelectedExerciseName = selectedExercise?.ToString(),
                CaloriesBurned = selectedExercise?.Calories * weightMultiplier * lengthMultiplier ?? 0
            };
            return View("CalorieResult", output);
        }
    }
}